@@ -16,7 +16,6 @@ import glob
 import grp
 import os
 import pwd
-import six
 import yaml
 
 from charmhelpers.core.hookenv import (
@@ -91,7 +90,7 @@ def _apply_overrides(settings, overrides, schema):
     :returns: dictionary of modules config with user overrides applied.
     """
     if overrides:
-        for k, v in six.iteritems(overrides):
+        for k, v in overrides.items():
             if k in schema:
                 if schema[k] is None:
                     settings[k] = v
