@@ -226,8 +226,6 @@ from functools import wraps
 import json
 import os.path
 
-from six import with_metaclass
-
 from charmhelpers.core import hookenv
 
 
@@ -244,7 +242,8 @@ class Singleton(type):
         return cls._instances[cls]
 
 
-class BaseCoordinator(with_metaclass(Singleton, object)):
+# class BaseCoordinator(with_metaclass(Singleton, object)):
+class BaseCoordinator(metaclass=Singleton):
     relid = None  # Peer relation-id, set by __init__
     relname = None
 
@@ -408,8 +407,8 @@ class BaseCoordinator(with_metaclass(Singleton, object)):
         for u in self.requests:
             if u in granted:
                 continue  # In the granted set. Not wanted in the req list.
-            for l, ts in self.requests[u].items():
-                if l == lock:
+            for _lock, ts in self.requests[u].items():
+                if _lock == lock:
                     reqs.add((ts, u))
         queue = [t[1] for t in sorted(reqs)]
         if unit not in queue:
@@ -465,7 +464,7 @@ class BaseCoordinator(with_metaclass(Singleton, object)):
         return self.__class__.__name__
 
     def _load_state(self):
-        self.msg('Loading state'.format(self._name()))
+        self.msg('Loading state')
 
         # All responses must be stored in the leadership settings.
         # The leader cannot use local state, as a different unit may
@@ -503,7 +502,7 @@ class BaseCoordinator(with_metaclass(Singleton, object)):
                 self.msg('Waiting on {}'.format(lock))
 
     def _save_state(self):
-        self.msg('Publishing state'.format(self._name()))
+        self.msg('Publishing state')
         if hookenv.is_leader():
             # sort_keys to ensure stability.
             raw = json.dumps(self.grants, sort_keys=True)
