@@ -17,12 +17,11 @@
 # Authors:
 #  Charm Helpers Developers <juju@lists.ubuntu.com>
 
-from __future__ import print_function
 import copy
 from distutils.version import LooseVersion
 from enum import Enum
 from functools import wraps
-from collections import namedtuple
+from collections import namedtuple, UserDict
 import glob
 import os
 import json
@@ -36,12 +35,6 @@ from subprocess import CalledProcessError
 
 from charmhelpers import deprecate
 
-import six
-if not six.PY3:
-    from UserDict import UserDict
-else:
-    from collections import UserDict
-
 
 CRITICAL = "CRITICAL"
 ERROR = "ERROR"
@@ -112,7 +105,7 @@ def log(message, level=None):
     command = ['juju-log']
     if level:
         command += ['-l', level]
-    if not isinstance(message, six.string_types):
+    if not isinstance(message, str):
         message = repr(message)
     command += [message[:SH_MAX_ARG]]
     # Missing juju-log should not cause failures in unit tests
@@ -132,7 +125,7 @@ def log(message, level=None):
 def function_log(message):
     """Write a function progress message"""
     command = ['function-log']
-    if not isinstance(message, six.string_types):
+    if not isinstance(message, str):
         message = repr(message)
     command += [message[:SH_MAX_ARG]]
     # Missing function-log should not cause failures in unit tests
@@ -445,12 +438,6 @@ def config(scope=None):
     """
     global _cache_config
     config_cmd_line = ['config-get', '--all', '--format=json']
-    try:
-        # JSON Decode Exception for Python3.5+
-        exc_json = json.decoder.JSONDecodeError
-    except AttributeError:
-        # JSON Decode Exception for Python2.7 through Python3.4
-        exc_json = ValueError
     try:
         if _cache_config is None:
             config_data = json.loads(
@@ -459,7 +446,7 @@ def config(scope=None):
         if scope is not None:
             return _cache_config.get(scope)
         return _cache_config
-    except (exc_json, UnicodeDecodeError) as e:
+    except (json.decoder.JSONDecodeError, UnicodeDecodeError) as e:
         log('Unable to parse output from config-get: config_cmd_line="{}" '
             'message="{}"'
             .format(config_cmd_line, str(e)), level=ERROR)
@@ -491,12 +478,26 @@ def relation_get(attribute=None, unit=None, rid=None, app=None):
         raise
 
 
+@cached
+def _relation_set_accepts_file():
+    """Return True if the juju relation-set command accepts a file.
+
+    Cache the result as it won't change during the execution of a hook, and
+    thus we can make relation_set() more efficient by only checking for the
+    first relation_set() call.
+
+    :returns: True if relation_set accepts a file.
+    :rtype: bool
+    :raises: subprocess.CalledProcessError if the check fails.
+    """
+    return "--file" in subprocess.check_output(
+        ["relation-set", "--help"], universal_newlines=True)
+
+
 def relation_set(relation_id=None, relation_settings=None, app=False, **kwargs):
     """Set relation information for the current unit"""
     relation_settings = relation_settings if relation_settings else {}
     relation_cmd_line = ['relation-set']
-    accepts_file = "--file" in subprocess.check_output(
-        relation_cmd_line + ["--help"], universal_newlines=True)
     if app:
         relation_cmd_line.append('--app')
     if relation_id is not None:
@@ -508,7 +509,7 @@ def relation_set(relation_id=None, relation_settings=None, app=False, **kwargs):
         # sites pass in things like dicts or numbers.
         if value is not None:
             settings[key] = "{}".format(value)
-    if accepts_file:
+    if _relation_set_accepts_file():
         # --file was introduced in Juju 1.23.2. Use it by default if
         # available, since otherwise we'll break if the relation data is
         # too big. Ideally we should tell relation-set to read the data from
