@@ -1,7 +1,6 @@
 from mock import patch, call, mock_open
 
 import collections
-import six
 import errno
 from shutil import rmtree
 from tempfile import mkdtemp
@@ -325,15 +324,15 @@ class CephUtilsTests(TestCase):
                           valid_range=[0])
 
     def test_validator_invalid_string_list(self):
-        # foo is a six.string_types that isn't in the valid string list
+        # foo is a str that isn't in the valid string list
         self.assertRaises(AssertionError, ceph_utils.validator,
                           value="foo",
-                          valid_type=six.string_types,
+                          valid_type=str,
                           valid_range=["valid", "list", "of", "strings"])
 
     def test_validator_valid_string(self):
         ceph_utils.validator(value="foo",
-                             valid_type=six.string_types,
+                             valid_type=str,
                              valid_range=["foo"])
 
     def test_validator_valid_string_type(self):
@@ -496,7 +495,8 @@ class CephUtilsTests(TestCase):
         p.create()
 
         self.check_call.assert_has_calls([
-            call(['ceph', '--id', 'admin', 'osd', 'pool', 'create', 'test', str(200)]),
+            call(['ceph', '--id', 'admin', 'osd', 'pool', 'create', 'test', str(200),
+                  'replicated_rule']),
             call(['ceph', '--id', 'admin', 'osd', 'pool', 'set', 'test', 'size', str(3)]),
         ])
         self.assertEqual(self.check_call.call_count, 2)
@@ -512,7 +512,7 @@ class CephUtilsTests(TestCase):
 
         self.check_call.assert_has_calls([
             call(['ceph', '--id', 'admin', 'osd',
-                  'pool', 'create', 'test', str(200)]),
+                  'pool', 'create', 'test', str(200), 'replicated_rule']),
             call(['ceph', '--id', 'admin', 'osd',
                   'pool', 'set', 'test', 'size', str(3)]),
             call(['ceph', '--id', 'admin', 'osd', 'pool',
@@ -532,7 +532,7 @@ class CephUtilsTests(TestCase):
         # at 100 PGs/OSD, the number of expected placement groups will be 16
         self.check_call.assert_has_calls([
             call(['ceph', '--id', 'admin', 'osd', 'pool', 'create', 'test',
-                  '16']),
+                  '16', 'replicated_rule']),
         ])
 
     @patch.object(ceph_utils, 'get_osds')
@@ -547,8 +547,9 @@ class CephUtilsTests(TestCase):
         # at 100 PGs/OSD, the number of expected placement groups will be 128
         self.check_call.assert_has_calls([
             call(['ceph', '--id', 'admin', 'osd', 'pool', 'create', 'test',
-                  '128']),
-            call(['ceph', '--id', 'admin', 'osd', 'pool', 'set', 'test', 'size', '3']),
+                  '128', 'replicated_rule']),
+            call(['ceph', '--id', 'admin', 'osd', 'pool', 'set', 'test',
+                  'size', '3']),
         ])
 
     @patch.object(ceph_utils, 'get_osds')
@@ -564,7 +565,8 @@ class CephUtilsTests(TestCase):
         # at 100 PGs/OSD, the number of expected placement groups will be 128
         self.check_call.assert_has_calls([
             call(['ceph', '--id', 'admin', 'osd', 'pool',
-                  'create', '--pg-num-min=32', 'test', '128']),
+                  'create', '--pg-num-min=32', 'test', '128',
+                  'replicated_rule']),
             call(['ceph', '--id', 'admin', 'osd', 'pool',
                   'set', 'test', 'size', '3']),
             call(['ceph', '--id', 'admin', 'osd', 'pool',
@@ -588,7 +590,7 @@ class CephUtilsTests(TestCase):
         # at 100 PGs/OSD, the number of expected placement groups will be 128
         self.check_call.assert_has_calls([
             call(['ceph', '--id', 'admin', 'osd', 'pool',
-                  'create', '--pg-num-min=2', 'test', '2']),
+                  'create', '--pg-num-min=2', 'test', '2', 'replicated_rule']),
             call(['ceph', '--id', 'admin', 'osd', 'pool',
                   'set', 'test', 'size', '3']),
             call(['ceph', '--id', 'admin', 'osd', 'pool',
@@ -612,7 +614,7 @@ class CephUtilsTests(TestCase):
         # will be 1024.
         self.check_call.assert_has_calls([
             call(['ceph', '--id', 'admin', 'osd', 'pool', 'create', 'test',
-                  '1024']),
+                  '1024', 'replicated_rule']),
         ])
 
     @patch.object(ceph_utils, 'get_osds')
@@ -628,7 +630,7 @@ class CephUtilsTests(TestCase):
         # will be 32768
         self.check_call.assert_has_calls([
             call(['ceph', '--id', 'admin', 'osd', 'pool', 'create', 'test',
-                  '32768']),
+                  '32768', 'replicated_rule']),
         ])
 
     @patch.object(ceph_utils, 'get_osds')
@@ -987,12 +989,25 @@ class CephUtilsTests(TestCase):
         self.assertRaises(CalledProcessError, ceph_utils.monitor_key_delete,
                           service='admin', key='foo')
 
-    def test_get_monmap(self):
+    @patch.object(ceph_utils, 'cmp_pkgrevno')
+    def test_get_monmap_pre_octopus(self, mock_cmp_pkgrevno):
+        mock_cmp_pkgrevno.return_value = -1
         self.check_output.return_value = MONMAP_DUMP
         cmd = ['ceph', '--id', 'admin',
                'mon_status', '--format=json']
         ceph_utils.get_mon_map(service='admin')
         self.check_output.assert_called_with(cmd)
+        mock_cmp_pkgrevno.assert_called_once_with('ceph-common', '15.0.0')
+
+    @patch.object(ceph_utils, 'cmp_pkgrevno')
+    def test_get_monmap_octopus_and_later(self, mock_cmp_pkgrevno):
+        mock_cmp_pkgrevno.return_value = 0
+        self.check_output.return_value = MONMAP_DUMP
+        cmd = ['ceph', '--id', 'admin',
+               'quorum_status', '--format=json']
+        ceph_utils.get_mon_map(service='admin')
+        self.check_output.assert_called_with(cmd)
+        mock_cmp_pkgrevno.assert_called_once_with('ceph-common', '15.0.0')
 
     @patch.object(ceph_utils, 'get_mon_map')
     def test_hash_monitor_names(self, monmap):
@@ -1000,9 +1015,7 @@ class CephUtilsTests(TestCase):
             '010d57d581604d411b315dd64112bff832ab92c7323fa06077134b50',
             '8e0a9705c1aeafa1ce250cc9f1bb443fc6e5150e5edcbeb6eeb82e3c',
             'c3f8d36ba098c23ee920cb08cfb9beda6b639f8433637c190bdd56ec']
-        _monmap_dump = MONMAP_DUMP
-        if six.PY3:
-            _monmap_dump = _monmap_dump.decode('UTF-8')
+        _monmap_dump = MONMAP_DUMP.decode('UTF-8')
         monmap.return_value = json.loads(_monmap_dump)
         hashed_mon_list = ceph_utils.hash_monitor_names(service='admin')
         self.assertEqual(expected=expected_hash_list, observed=hashed_mon_list)
@@ -2036,6 +2049,7 @@ class CephUtilsTests(TestCase):
                    'compression-min-blob-size-ssd': None,
                    'compression-mode': None,
                    'compression-required-ratio': None,
+                   'crush-profile': None,
                    'group': None,
                    'group-namespace': None,
                    'max-bytes': None,
