@@ -8,11 +8,7 @@ from mock import (
     patch,
 )
 
-import six
-if six.PY3:
-    from urllib.parse import urlparse
-else:
-    from urlparse import urlparse
+from urllib.parse import urlparse
 
 try:
     from charmhelpers.fetch import (
