@@ -4,12 +4,6 @@ import yaml
 
 import tools.charm_helpers_sync.charm_helpers_sync as sync
 
-import six
-if not six.PY3:
-    builtin_open = '__builtin__.open'
-else:
-    builtin_open = 'builtins.open'
-
 
 INCLUDE = """
 include:
@@ -53,7 +47,7 @@ class HelperSyncTests(unittest.TestCase):
         self.assertEquals('/tmp/mycharm/hooks/charmhelpers/contrib/openstack',
                           path)
 
-    @patch(builtin_open)
+    @patch('builtins.open')
     @patch('os.path.exists')
     @patch('os.walk')
     def test_ensure_init(self, walk, exists, _open):
@@ -121,7 +115,7 @@ class HelperSyncTests(unittest.TestCase):
         isfile.side_effect = _isfile
         isdir.side_effect = _isdir
         result = sync.get_filter(opts)(dir='/tmp/charm-helpers/core',
-                                       ls=six.iterkeys(files))
+                                       ls=files.keys())
         return result
 
     @patch('os.path.isdir')
@@ -215,10 +209,12 @@ class HelperSyncTests(unittest.TestCase):
 
     @patch('tools.charm_helpers_sync.charm_helpers_sync.sync')
     @patch('os.path.isdir')
-    def test_sync_helpers_from_config(self, isdir, _sync):
+    @patch('os.path.exists')
+    def test_sync_helpers_from_config(self, exists, isdir, _sync):
         '''It correctly syncs a list of included helpers'''
-        include = yaml.load(INCLUDE)['include']
+        include = yaml.safe_load(INCLUDE)['include']
         isdir.return_value = True
+        exists.return_value = False
         sync.sync_helpers(include=include,
                           src='/tmp/charm-helpers',
 
@@ -239,6 +235,38 @@ class HelperSyncTests(unittest.TestCase):
         ) for c in mods]
         self.assertEquals(ex_calls, _sync.call_args_list)
 
+    @patch('tools.charm_helpers_sync.charm_helpers_sync.sync')
+    @patch('os.path.isdir')
+    @patch('os.path.exists')
+    @patch('shutil.rmtree')
+    def test_sync_helpers_from_config_cleanup(self, _rmtree, _exists,
+                                              isdir, _sync):
+        '''It correctly syncs a list of included helpers'''
+        include = yaml.safe_load(INCLUDE)['include']
+        isdir.return_value = True
+        _exists.return_value = True
+
+        sync.sync_helpers(include=include,
+                          src='/tmp/charm-helpers',
+
+                          dest='hooks/charmhelpers')
+        _rmtree.assert_called_with('hooks/charmhelpers')
+        mods = [
+            'core',
+            'contrib.openstack',
+            'contrib.storage',
+            'contrib.hahelpers.utils',
+            'contrib.hahelpers.ceph_utils',
+            'contrib.hahelpers.cluster_utils',
+            'contrib.hahelpers.haproxy_utils'
+        ]
+
+        ex_calls = []
+        [ex_calls.append(
+            call('/tmp/charm-helpers', 'hooks/charmhelpers', c, [])
+        ) for c in mods]
+        self.assertEquals(ex_calls, _sync.call_args_list)
+
     def test_extract_option_no_globals(self):
         '''It extracts option from an included item with no global options'''
         inc = 'contrib.openstack.templates|inc=*.template'
